summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/kopetepasswordwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/ui/kopetepasswordwidget.h')
-rw-r--r--kopete/libkopete/ui/kopetepasswordwidget.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kopete/libkopete/ui/kopetepasswordwidget.h b/kopete/libkopete/ui/kopetepasswordwidget.h
index 72834bff..e8c45a90 100644
--- a/kopete/libkopete/ui/kopetepasswordwidget.h
+++ b/kopete/libkopete/ui/kopetepasswordwidget.h
@@ -37,15 +37,16 @@ namespace UI
class KOPETE_EXPORT PasswordWidget : public KopetePasswordWidgetBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a Kopete::PasswordWidget.
* @param parent The widget to nest this one inside
* @param name The name of this QObject
* @param from The password to load the data for this widget from, or 0 if none
*/
- PasswordWidget( TQWidget *parent, const char *name = 0, Kopete::Password *from = 0 );
+ PasswordWidget( TQWidget *tqparent, const char *name = 0, Kopete::Password *from = 0 );
~PasswordWidget();
/**
@@ -37,15 +37,16 @@ namespace UI
/**
* Creates a Kopete::PasswordWidget.
- * @param parent The widget to nest this one inside
- * @param name The name of this QObject
+ * @param tqparent The widget to nest this one inside
+ * @param name The name of this TQObject
* @param from The password to load the data for this widget from, or 0 if none
*/